# ## Open a NetCDF file and read a rectilinear grid

# ### Import required modules

import Nio as nio
import numpy as np

filename = "../Data/ts_Amon_CESM1-CAM5_historical_r1i1p1_185001-200512_partial.nc"
f   = nio.open_file(filename)
#print(f)

# ### Print all the variables on the file

vnames = f.variables.keys()
print vnames


# ### Read ts, lat, lon off the file

ts  = f.variables["ts"]           # Get the "ts" variable object
lat = f.variables["lat"][:]       # [:] reads the values
lon = f.variables["lon"][:]

# ### Print some info about variables

print "ts type",type(ts)
print "lat type",type(lat)
print "lon type",type(lon)
print "ts dimension sizes",ts.shape
print "lat dimension sizes",lat.shape
print "lon dimension sizes",lon.shape

# ### Print attributes and dimension names of ts

print "Attributes",     ts.attributes
print "Dimension names",ts.dimensions

# ### Accessing individual attributes and dimension names

print "Variable is %s (%s)" % (ts.long_name,ts.units)
print "Name of dimension 0 is", ts.dimensions[0]


# ### Use [:] to access values

tvals = ts[:]             # Reads all dimensions, all values
print "type",type(tvals)
print "shape",tvals.shape
print "dtype = %s" % tvals.dtype
print tvals

# Two ways to get the min/max

print "min / max = %g / %g" % (np.min(tvals),np.max(tvals))
print "min / max = %g / %g" % (tvals.min(),tvals.max())
print "average = ",np.average(tvals)

# ### Create a contour plot using PyNGL

from plot_ts_Amon_ngl import *
plot_ts_Amon_ngl(ts,lat,lon)
#from IPython.display import Image
#Image(filename='plot_ts_Amon.png')


# ### Subset "ts" using coordinate subscripting

ts  = f.variables["ts"]['time|i0 lat|0:60 lon|45:135']
print ts.shape

# #### Exercise: use coordinate subscripting to subscript lat/lon arrays using the same lat/lon range as "ts", and plot using "plot_ts_Amon_subset_ngl".
# (Note: the plotting code will be similar to the one above, but the routine name and the PNG file name are different.)
