# ## Open a WRF output file with a curvilinear grid

# ### Import required modules

import Nio as nio
import numpy as np


# ### Open the file, don't forget to add the ".nc"
filename="../Data/wrfout_d03_2012-04-22_23_00_00.nc"
f = nio.open_file(filename)

# ### Print all the variables on the file

vnames = f.variables.keys()
print vnames


# ### Read "HGT" variable off file

h = f.variables["HGT"]

# ### Print some information about "h"

print "type",type(h)
print "dimension sizes",h.shape


# ### Print attributes and dimension names of "h"

print "Attributes",     h.attributes
print "Dimension names",h.dimensions


# ### Accessing individual attributes and dimension names

print "Variable is %s (%s)" % (h.description,h.units)
print "Name of dimension 0 is", h.dimensions[0]

# ### Use [:] to access values

hvals = h[:]             # Reads all dimensions, all values
print "type",type(hvals)
print "shape",hvals.shape
print "dtype = %s" % hvals.dtype
print hvals

# Two ways to get the min/max
print "min / max = %g / %g" % (np.min(hvals),np.max(hvals))
print "min / max = %g / %g" % (hvals.min(),hvals.max())
print "average = ",np.average(hvals)


# ## Reread "hgt" variable as numpy array
# "h" is a 3D variable (time,lat,lon), so be sure to subscript it.

h = f.variables["HGT"][0,:,:]
print "type(h)",type(h)
print "h.shape",h.shape
print h.min(),h.max()

# ## Create a color contour plot using PyNGL

from wrf_plot_ngl import *
wrf_plot_var(h,contour_type="raster")
#wrf_plot_from_file(filename,"HGT",contour_type="raster")
#from IPython.display import Image
#Image(filename='wrfplot.png')

# ## Create a contour plot using matplotlib

#get_ipython().magic(u'matplotlib inline')
#from wrf_plot_hgt_mpl import WRF_Plotter
#wplt = WRF_Plotter(fname = "../Data/wrfout_d03_2012-04-22_23_00_00", vname = "HGT")
#wplt.plot(varname = 'HGT')
#wplt.close()


# ### Exercise: read and plot "T2" using wrf_plot_from_file, or wrf_plot_var, or wrf_plot_T2_mpl to plot.
