#import matplotlib
#matplotlib.use('agg')

#import matplotlib.axes as maxes

import matplotlib.pyplot as plt
import matplotlib.cm as cm
import numpy as np

import os, sys
import sys,getopt

#from datetime import datetime, timedelta
#from matplotlib.colors import LinearSegmentedColormap
#from mpl_toolkits.axes_grid import make_axes_locatable

from mpl_toolkits.basemap import Basemap

import Nio

class WRF_Plotter:
    def __init__(self, fname = None, vname = None, show = True):
        self.name = fname
        self.var = vname
	self.show = show
       #print "fname: ", fname
       #print "vname: ", vname

        self.setup()

    def setup(self):
	print "fname: ", self.name
        if(os.path.exists(self.name)):
            self.file = Nio.open_file(self.name + ".nc", "r")
        else:
	    print "file: <%s> does not exit. exit." %(self.name)
	    exit(-1);

	dims = self.file.dimensions
	self.nx = dims['west_east']
	self.ny = dims['south_north']
	self.nz = dims['bottom_top']

	atts = self.file.attributes
	self.cen_lon = atts['CEN_LON']
	self.cen_lat = atts['CEN_LAT']

	self.dx = atts['DX']
	self.dy = atts['DY']

        self.j_parent_start = atts['J_PARENT_START']
        self.i_parent_start = atts['I_PARENT_START']

	self.truelat1 = atts['TRUELAT1']
	self.truelat2 = atts['TRUELAT2']

	self.map_proj = atts['MAP_PROJ']
        self.parent_id = atts['PARENT_ID']

        self.grid_ratio = atts['PARENT_GRID_RATIO']
	self.moad_cen_lat = atts['MOAD_CEN_LAT']
	self.stand_lon = atts['STAND_LON']

	self.mx = atts['WEST-EAST_GRID_DIMENSION']
	self.my = atts['SOUTH-NORTH_GRID_DIMENSION']
	self.mz = atts['BOTTOM-TOP_GRID_DIMENSION']

	self.xlon = self.file.variables['XLONG'][0, :, :]
	self.xlat = self.file.variables['XLAT'][0, :, :]

        self.lat_ll = self.xlat[0,0]
	self.lat_ur = self.xlat[-1,-1]
	self.lon_ll = self.xlon[0,0]
	self.lon_ur = self.xlon[-1,-1]

       #print "lat_ll, lat_ur = ", self.lat_ll, self.lat_ur
       #print "lon_ll, lon_ur = ", self.lon_ll, self.lon_ur

       #self.dump()

	self.width_meters = self.dx * (self.mx - 1)
	self.height_meters = self.dy * (self.my - 1)

       #self.basemap = Basemap(resolution='i',projection='lcc',
       #                       width=self.width_meters, height=self.height_meters,
       #                       lat_0=self.cen_lat, lon_0=self.cen_lon,
       #		       lat_1=self.truelat1, lat_2=self.truelat2)

       #		       lon_0=self.cen_lon,
       #		       lat_0=self.cen_lat,

        self.basemap = Basemap(projection='lcc',
			       lon_0=self.stand_lon,
			       lat_0=self.moad_cen_lat,
			       lat_1=self.truelat1,
			       lat_2=self.truelat2,
		               llcrnrlat=self.lat_ll,
			       urcrnrlat=self.lat_ur,
                               llcrnrlon=self.lon_ll,
			       urcrnrlon=self.lon_ur,
			       resolution='h')

       #compute native x,y coordinates of grid.
        self.x, self.y = self.basemap(self.xlon, self.xlat)

       #Set universal figure margins
       #self.width = 10
       #self.height = 8

       #plt.figure(figsize=(self.width, self.height))
       #plt.rc("figure.subplot", left = .001)
       #plt.rc("figure.subplot", right = .999)
       #plt.rc("figure.subplot", bottom = .001)
       #plt.rc("figure.subplot", top = .999)

    def plot(self, varname = 'T2'):
        var = self.file.variables[varname][0, :, :]

       #create figure, add axes
	fig = plt.figure(figsize=(8,8))
	ax = fig.add_axes([0.1,0.1,0.8,0.8])

       #set desired contour levels.
       #clevs = np.arange(3000,3200,20)
       #chgts = np.arange(0,4000,250)

       #CS1 = self.basemap.contourf(self.x,self.y,hgts,chgts,cmap=plt.cm.terrain,animated=True)
       #CS2 = self.basemap.contour(self.x,self.y,slp,clevs,linewidths=0.5,colors='k',animated=True)
       #plt.clabel(CS2, inline=2, fmt=r'%1.0f', fontsize=10)

       #plot contours.
        clevs = np.arange(274, 312, 1)
	CS1 = self.basemap.contourf(self.x, self.y, var, clevs,
        		            cmap=cm.jet, animated=True)
       #		            cmap=cm.Spectral, animated=True)
       #		            cmap=cm.coolwarm, animated=True)
       #		            cmap=plt.cm.terrain, animated=True)

       #define parallels and meridians to draw.
	parallels = np.arange(34., 42, 2.)
	meridians = np.arange(-124., -116., 2.)
	self.basemap.drawcoastlines(linewidth=1.5)
       #self.basemap.drawparallels(parallels)
       #self.basemap.drawmeridians(meridians)
        self.basemap.drawparallels(parallels,labels=[1,0,0,0],fontsize=10)
        self.basemap.drawmeridians(meridians,labels=[0,0,0,1],fontsize=10)

       #add colorbar
	cb = self.basemap.colorbar(CS1,"bottom", size="5%", pad="5%")
	cb.set_label(varname)

       #set plot title
       #ax.set_title(str(pres) + ' hPa Geopotential height '+ str(cdate))
	ax.set_title(varname)

	outfig = 'WRF_%s.png' %str(varname)
	plt.savefig(outfig, bbox_inches='tight')

	if(self.show):
	    plt.show()

	plt.close(fig)

    def dump(self):
       #print self.file
	print "center lat, lon: (%f, %f)" %(self.cen_lat, self.cen_lon)
	print "truelat1, truelat2: (%f, %f)" %(self.truelat1, self.truelat2)
	print "dx, dy: (%f, %f)" %(self.dx, self.dy)
	print "mx, my, mz: (%d, %d, %d)" %(self.mx, self.my, self.mz)
	print "parent start i,j: (%d, %d)" %(self.i_parent_start, self.j_parent_start)
	print "map_proj: %d" %(self.map_proj)
	print "parent_id, grid_ratio: (%d, %d)" %(self.parent_id, self.grid_ratio)
	print "moad_cen_lat, stand_lon: (%f, %f)" %(self.moad_cen_lat, self.stand_lon)

    def close(self):
        self.file.close()

if __name__ == '__main__':
    default_filename = "../Data/wrfout_d03_2005-08-30_00:00:00"
   #default_filename = "../py4wh/wrfdata/wrfout_d01_2010-06-12_12:00:00"

   #if(len(sys.argv) > 1):
   #    name = sys.argv[1]
   #else:
   #    print "Usage: %s filename" %(sys.argv[0])
   #    exit(-1)

    fname = None
    filename = None
    var = None
    export_flag = 0
    restart_time = 0

   #f --> the name of the domain we want to use
    (opts,args)=getopt.getopt(sys.argv[1:],'f:v')
    for o,a in opts:
        if o=="-f":
            fname = str(a)
        if o=="-v":
            var = str(a)

    if(None == fname):
        if(os.path.isfile(default_filename)):
            fname = default_filename

    if(None == fname):
	print "Usage: %s -f filename [-v varname]" %(sys.argv[0])
	exit(-1)

    wplt = WRF_Plotter(fname = fname, vname = var)
   #wplt.dump()
    wplt.plot(varname = 'T2')
    wplt.close()

