import numpy, Nio, Ngl

def wrf_unstagger(x,dim):
  rank = len(x.shape)
  if(rank == 4 and dim == "u"):
    xu = 0.5*(x[:,:,:,:-1] + x[:,:,:,1:])
  elif(rank == 4 and dim == "v"):
    xu = 0.5*(x[:,:,:-1,:] + x[:,:,1:,:])
  if(rank == 3 and dim == "u"):
    xu = 0.5*(x[:,:,:-1] + x[:,:,1:])
  elif(rank == 3 and dim == "v"):
    xu = 0.5*(x[:,:-1,:] + x[:,1:,:])
  elif(rank == 2 and dim == "u"):
    xu = 0.5*(x[:,:-1] + x[:,1:])
  elif(rank == 2 and dim == "v"):
    xu = 0.5*(x[:-1,:] + x[1:,:])
  return xu

#---Read data
filename = "../Data/wrfout_d03_2012-04-22_23_00_00_uv_partial.nc"
a    = Nio.open_file(filename)
u    = a.variables["U"]
v    = a.variables["V"]
latu = a.variables["XLAT_U"]
lonu = a.variables["XLONG_U"]

ua  = wrf_unstagger(u,"u")
va  = wrf_unstagger(v,"v")
lat = wrf_unstagger(latu,"u")
lon = wrf_unstagger(lonu,"u")

#---First timestep, lowest (bottommost) level, every 5th lat/lon
nl    = 0
nt    = 0
nstep = 5
u10 = ua[nt,nl,::nstep,::nstep]
v10 = va[nt,nl,::nstep,::nstep]
spd = numpy.sqrt(u10**2+v10**2)                

wks = Ngl.open_wks("x11","wrf_plot_UV_ngl")

res                   = Ngl.Resources()

res.mpDataBaseVersion = "MediumRes"           # Better map outlines
res.mpLimitMode       = "LatLon"              # Zoom in on map area of interest
res.mpMinLatF         = numpy.min(lat[:])-1
res.mpMaxLatF         = numpy.max(lat[:])+1
res.mpMinLonF         = numpy.min(lon[:])-1
res.mpMaxLonF         = numpy.max(lon[:])+1

res.mpFillOn          = True
res.mpLandFillColor   = "tan"
res.mpOceanFillColor  = "transparent"
res.mpInlandWaterFillColor  = "transparent"
res.mpGridLatSpacingF = 1
res.mpGridLonSpacingF = 1
#res.mpGridAndLimbOn   = False
 
res.stLineThicknessF  = 3.0                   # Thicker streamlines
res.stMonoLineColor   = False                 # Use multiple colors for streamlines

res.tiMainString      = "U10/V10 streamlines color by wind speed"

# Necessary to overlay on map correctly.
res.vfYArray          = lat[0,::nstep,::nstep]
res.vfXArray          = lon[0,::nstep,::nstep]

plot = Ngl.streamline_scalar_map(wks,u10,v10,spd,res)

Ngl.end()

